==> apache-camel-2.17.7-src.zip: apache-camel-2.17.7/camel-core/src/test/java/org/apache/camel/impl/ConsumerCacheZeroCapacityTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Endpoint;
import org.apache.camel.PollingConsumer;

/**
 * @version 
 */
public class ConsumerCacheZeroCapacityTest extends ContextTestSupport {

    public void testConsumerCacheZeroCapacity() throws Exception {
        ConsumerCache cache = new ConsumerCache(this, context, 0);
        cache.start();

        assertEquals("Size should be 0", 0, cache.size());

        Endpoint endpoint = context.getEndpoint("file:target/foo?fileName=foo.txt");
        PollingConsumer consumer = cache.acquirePollingConsumer(endpoint);
        assertNotNull(consumer);
        assertEquals("Started", ((org.apache.camel.support.ServiceSupport) consumer).getStatus().name());

        // let it run a poll
        consumer.receive(1000);

        cache.releasePollingConsumer(endpoint, consumer);

        // takes a little to stop
        Thread.sleep(1000);

        assertEquals("Stopped", ((org.apache.camel.support.ServiceSupport) consumer).getStatus().name());

        cache.stop();
    }

}

==> apache-camel-2.18.5-src.zip: apache-camel-2.18.5/camel-core/src/test/java/org/apache/camel/impl/ConsumerCacheZeroCapacityTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Endpoint;
import org.apache.camel.PollingConsumer;

/**
 * @version 
 */
public class ConsumerCacheZeroCapacityTest extends ContextTestSupport {

    public void testConsumerCacheZeroCapacity() throws Exception {
        ConsumerCache cache = new ConsumerCache(this, context, 0);
        cache.start();

        assertEquals("Size should be 0", 0, cache.size());

        Endpoint endpoint = context.getEndpoint("file:target/foo?fileName=foo.txt");
        PollingConsumer consumer = cache.acquirePollingConsumer(endpoint);
        assertNotNull(consumer);
        assertEquals("Started", ((org.apache.camel.support.ServiceSupport) consumer).getStatus().name());

        // let it run a poll
        consumer.receive(1000);

        boolean found = Thread.getAllStackTraces().keySet().stream().anyMatch(t -> t.getName().contains("target/foo"));
        assertTrue("Should find file consumer thread", found);

        cache.releasePollingConsumer(endpoint, consumer);

        // takes a little to stop
        Thread.sleep(1000);

        assertEquals("Stopped", ((org.apache.camel.support.ServiceSupport) consumer).getStatus().name());

        // should not be a file consumer thread
        found = Thread.getAllStackTraces().keySet().stream().anyMatch(t -> t.getName().contains("target/foo"));
        assertFalse("Should not find file consumer thread", found);

        cache.stop();
    }

}
